@@ -3,7 +3,9 @@ ENGLISH language string literals for PyGPSClient application
 
 Created on 12 Sep 2020
 
-@author: semuadmin
+:author: semuadmin
+:copyright: SEMU Consulting © 2020
+:license: BSD 3-Clause
 """
 # pylint: disable=line-too-long
 
@@ -13,7 +15,7 @@ COPYRIGHTTXT = "\u00A9 SEMU Consulting 2020\nBSD 3 License. All Rights Reserved"
 
 INTROTXT = "Welcome to PyGPSClient!"
 INTROTXTNOPORTS = (
-    "Welcome to PyGPSClient! Please connect a serial GPS device and restart."
+    "Welcome to PyGPSClient! Please connect a serial GNSS device and click refresh."
 )
 
 HELPTXT = "Help..About - display About dialog."
